## xlinjietool
- 打造集成工具库
---
### 总览
- amazon(亚马逊解析)
- db(数据库)
- headers(header头解析)
#### amazon(亚马逊解析)
> 各个站点日期解析<br>
> 站点链接组装<br>
#### db(数据库)
> es<br>
> redis<br>
> mysql<br>
#### headers(header头解析)
> 把web复制的headers解析成为json
